/*!
 * arr-diff <https://github.com/jonschlinkert/arr-diff>
 *
 * Copyright (c) 2014 Jon Schlinkert, contributors.
 * Licensed under the MIT License
 */

'use strict';

/**
 * Expose `diff`
 */

module.exports = diff;

/**
 * Return the difference between two arrays.
 *
 * ```js
 * var a = ['a', 'b', 'c', 'd'];
 * var b = ['b', 'c'];
 *
 * console.log(difference(a, b))
 * //=> ['a', 'd']
 * ```
 *
 * @param  {Array} `a`
 * @param  {Array} `b`
 * @return {Array}
 * @api public
 */

function diff(a, b) {
  var len = a.length;
  var arr = [];

  if (b == null || b.length === 0) {
    return a;
  }

  while (len--) {
    if (b.indexOf(a[len]) === -1) {
      arr.push(a[len]);
    }
  }
  return arr;
}